==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-storage-api/src/main/java/org/apache/streampipes/storage/api/IUserStorage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.storage.api;

import org.apache.streampipes.model.client.user.Principal;
import org.apache.streampipes.model.client.user.ServiceAccount;
import org.apache.streampipes.model.client.user.UserAccount;

import java.util.List;

public interface IUserStorage {

  List<Principal> getAllUsers();

  List<UserAccount> getAllUserAccounts();

  List<ServiceAccount> getAllServiceAccounts();

  Principal getUser(String username);

  UserAccount getUserAccount(String username);

  ServiceAccount getServiceAccount(String username);

  void storeUser(Principal user);

  void updateUser(Principal user);

  boolean checkUser(String username);

  void deleteUser(String principalId);

  Principal getUserById(String principalId);

}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-storage-api/src/main/java/org/apache/streampipes/storage/api/IUserStorage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.storage.api;

import org.apache.streampipes.model.client.user.Principal;
import org.apache.streampipes.model.client.user.ServiceAccount;
import org.apache.streampipes.model.client.user.UserAccount;

import java.util.List;

public interface IUserStorage {

  List<Principal> getAllUsers();

  List<UserAccount> getAllUserAccounts();

  List<ServiceAccount> getAllServiceAccounts();

  Principal getUser(String username);

  UserAccount getUserAccount(String username);

  ServiceAccount getServiceAccount(String username);

  void storeUser(Principal user);

  void updateUser(Principal user);

  boolean checkUserExists(String username);

  void deleteUser(String principalId);

  Principal getUserById(String principalId);

  boolean existsDatabase();

}
